@@ -18,6 +18,7 @@
 #include "fcompare.h"
 #include "../../include/VandP.h"
 #include "vp.h"
+#include "n_proc.h"
 #include "dynamic_cs.h"
   
 char  * libDir=NULL;
@@ -259,6 +260,7 @@ numout*getMEcode(int twidth,int Gauge, char*Process, char*excludeVirtual,
       if(!handle)
       {
         char options[20];
+        char nPROCSSch[20];
         char GaugeCh[4];
         int ret;  
         int delWorkDir;
@@ -274,6 +276,10 @@ numout*getMEcode(int twidth,int Gauge, char*Process, char*excludeVirtual,
         if(excludeVirtual) sprintf(command+strlen(command)," \"%s\"",excludeVirtual);
         else  sprintf(command+strlen(command)," \"\"");            
         if(excludeOut) sprintf(command+strlen(command)," \"%s\"",excludeOut);       
+
+        sprintf(nPROCSSch,"%d",nPROCSS);
+        setenv("nParProc",nPROCSSch,1);
+        
         ret=system(command);
       
         if(ret<0 || WIFSIGNALED(ret)>0 ) exit(10);
