@@ -12,6 +12,8 @@
 
 #define VVmassGap  70
 
+extern  char * trim(char *);
+
 int ForceUG=0;
 decayTableStr* decayTable=NULL;
 
@@ -399,7 +401,7 @@ void massFilter(double M, txtList * List)
             case 4: dM=1.5; break;
             case 5: dM=5. ; break;
           }
-       }  
+       }else if(abs(ModelPrtcls[abs(n)-1].NPDG)==6) dM=MtEff(0);  
        else  dM = fabs(*(varAddress(nm))); 
        Msum+=dM;
      } 
