@@ -344,7 +344,7 @@ int readVegasGrid(FILE * f)
     fscanf(f," Max(%ld):\n",&nCubes);   
     
     setEventCubes(veg_Ptr, nCubes);
-    if(veg_Ptr->evnCubes==nCubes) 
+    if(nCubes && veg_Ptr->evnCubes==nCubes) 
     { long l;
       veg_Ptr->fMax=malloc(sizeof(float)*veg_Ptr->evnCubes);
       for(l=0;l<veg_Ptr->evnCubes;l++) fscanf(f,"%f",veg_Ptr->fMax+l);
@@ -438,9 +438,6 @@ int runVegas(void)
     i=imkmom(inP1,inP2);
     if(veg_Ptr&&veg_Ptr->dim!=i)clearGrid();
     if(!veg_Ptr) veg_Ptr=vegas_init(i,func_,50);     
-    if(!veg_Ptr->evnCubes) 
-    {  setEventCubes(veg_Ptr, EventGrid);
-    }  EventGrid=veg_Ptr->evnCubes;
 
     if(nin_int == 2) strcpy(mess, "Cross section[pb]");
       else           strcpy(mess, "   Width[Gev]    ");
@@ -499,13 +496,17 @@ int runVegas(void)
           correctLong(50,12,"Enter new value ",&integral.ncall[0],1); break;
         case 3:  editHist(); break;
         case 4:
-          if(veg_Ptr->fMax && !integral.freeze)
+          if(veg_Ptr->fMax && !integral.freeze) 
           {  if(!mess_y_n(15,15,"You have event generator prepared.\n"
              " The  answer 'Y'  will start Vegas session \nwhich destroys it."
              " To save the event generator answer 'N' \nand set "
              " ' Freeze grid' ON")) break;
              else { free(veg_Ptr->fMax); veg_Ptr->fMax=NULL; veg_Ptr->evnCubes=0;}  
           }
+          if(!veg_Ptr->fMax && integral.freeze)
+          {  setEventCubes(veg_Ptr, EventGrid);
+             EventGrid=veg_Ptr->evnCubes;
+          }
 
           for (i = 1; i <= integral.itmx[0]; ++i)                                       
           { char  errtxt[100]="";
