@@ -30,7 +30,7 @@ static double xMin[2]={0,0},xMax[2]={0,0},qMin[2]={1,1},qMax[2]={1E10,1E10};
 
 static int nGroup[2]={3,3}, nSet[2]={41,41}, sgn[2]={1,1},lastLHA=0;
 
-static int parton[15]={83,81,2,1,4,3,5,21,-5,-3,-4,-1,-2,-81,-83};
+static int parton[11]={2,1,4,3,5,21,-5,-3,-4,-1,-2};
 
 static int pnum[2]={0,0};
 
@@ -70,8 +70,8 @@ int p_lha(int * pNum)
   int i;
   if(!initLHA())return 0;
   for(;*pNum;pNum++) 
-  { for(i=0;i<15;i++) if(*pNum==parton[i]) break;
-    if(i==15) return 0;
+  { for(i=0;i<11;i++) if(*pNum==parton[i]) break;
+    if(i==11) return 0;
   }
   return 1;
 }
@@ -97,7 +97,7 @@ int init_lha(int i,double * be, double * mass)
    *mass=0.9383;
    *be=1;
    sf_alpha=&(alpha_lha);   
-   for(k=0;k<15;k++) if(parton[k]==N) {pnum[i-1]=N; return 1;}
+   for(k=0;k<11;k++) if(parton[k]==N) {pnum[i-1]=N; return 1;}
    pnum[i-1]=0; 
    return 0;
 }
@@ -188,7 +188,7 @@ int r_lha(int i, char *name)
   char*men,*c;
   int max;
   if(!initLHA())return 0; 
-  if(3!=sscanf(name,"LHA:%[^:]%*c%d:%d",txt+1,setNum+i1,sgn+i1)) return 0;  
+  if(3!=sscanf(name,"LHA:%[^:]:%d:%d",txt+1,setNum+i1,sgn+i1)) return 0;  
   if(abs(sgn[i1])!=1) return 0;
   men=lhaMenu();
 
@@ -247,7 +247,7 @@ int m_lha(int i,int*pString)
   else 
   { fname[i1][0]=0;
     setNum[i1]=0;
-    sgn[i1]=0;
+    sgn[i1]=1;
     return 0;
   } 
 
