@@ -4,11 +4,12 @@
 #include "physics.h"
 #include "syst.h"
 #include "ghosts.h"
+#include "process.h"
 
 #define S_PERMIT 8
 #define V_PERMIT 16
-#define T_PERMIT 32
-
+#define X_PERMIT 32
+#define Y_PERMIT 64
 
 j_lgrptr j_lgrarray[2 * maxvert];
 
@@ -157,6 +158,7 @@ static void  makeSkelet(void)
    for (i = 0; i < vcs_stat.sizet; i++)   /*  mark subgraph vertex with '1'  */ 
       for (j = 0; j < vcs_stat.valence[i]; j++) 
       { 
+/*       if(PLR_PRTCL&vcs_stat.vertlist[i][j].prop) continue;*/
          i1 = vcs_stat.vertlist[i][j].nextvert.vno - 1 ; 
          p = vcs_stat.vertlist[i][j].partcl; 
          if (gaugep(p) && i < i1) 
@@ -354,11 +356,14 @@ static void  insertPermition(hlpcsptr alll)
           if (gaugep(np) && !zeromass(np) && prtclInVert(np+sbosonmark,i+1) 
           && prtclInVert(prtclbase[np+sbosonmark-1].anti,i1+1) )mark +=S_PERMIT;
 
-          if ( (prtclbase[np-1].spin == 2) && (prtclbase[np-1].cdim !=1) &&
-          ( (i >= vcs_stat.sizel) || (i1 < vcs_stat.sizel) ) &&
-          prtclInVert(np+tbosonmark,i+1)   
-          && prtclInVert(prtclbase[np+tbosonmark-1].anti,i1+1 )) mark += T_PERMIT; 
+          if ( (prtclbase[np-1].spin == 2) /*&& (prtclbase[np-1].cdim !=1)*/ &&
+          ( (i >= vcs_stat.sizel) || (i1 < vcs_stat.sizel) ))
+          {  if(prtclInVert(prtclbase[np+xbosonmark-1].anti,i1+1)
+             && prtclInVert(np+xbosonmark,i+1)) mark += X_PERMIT; 
 
+             if(prtclInVert(prtclbase[np+ybosonmark-1].anti,i1+1 )
+             && prtclInVert(np+ybosonmark,i+1)) mark += Y_PERMIT; 
+          }
           first_mark[i ][j ]=mark; 
           first_mark[i1][j1]=mark;   
        }    
@@ -432,8 +437,6 @@ static void  insertcopy(hlpcsptr c)
 } 
 
 
-
-
 static int  ins_test(int i,int  j,int  mrk,hlpcsptr  c)
 {int      j1; 
  algvertptr   lgr; 
@@ -482,9 +485,12 @@ static void  insert_v_s_t(hlpcsptr* alll)
                   if ( ( S_PERMIT & lineMark ) &&  ins_test(i,j,sbosonmark,c) 
                       && ins_test(i1,j1,sbosonmark,c)  ) 
                   { markList[l] = sbosonmark; l++;}
-                  if ( ( T_PERMIT & lineMark ) && ins_test(i,j,tbosonmark,c) 
-                      && ins_test(i1,j1,tbosonmark,c)  ) 
-                  { markList[l] = tbosonmark; l++;}
+                  if ( ( X_PERMIT & lineMark ) && ins_test(i,j,xbosonmark,c) 
+                      && ins_test(i1,j1,xbosonmark,c)  ) 
+                  { markList[l] = xbosonmark; l++;}
+                  if ( ( Y_PERMIT & lineMark ) && ins_test(i,j,ybosonmark,c) 
+                      && ins_test(i1,j1,ybosonmark,c)  ) 
+                  { markList[l] = ybosonmark; l++;}
                   
                   if (l==0 ) { del=1; goto label_1;} else
                   {  for (k=0;k<=l-2;k++)
@@ -546,36 +552,49 @@ static void  numerate(hlpcsptr alll)
 
 static void  setLorInd(hlpcsptr alll)
 {  
-  int i,j,i1,j1,np, ind,lorCount;
+  int i,j,i1,j1,np, ind1, ind2, lorCount;
   hlpcsptr    tmp; 
   lorCount=0;
   for (i=0;i<vcs_stat.sizet;i++)
   for (j=0;j<vcs_stat.valence[i];j++)
   { 
-    i1=vcs_stat.vertlist[i][j].nextvert.vno -1;
+    i1=vcs_stat.vertlist[i][j].link.vno;
     if (i < i1)
     {   
-       j1=vcs_stat.vertlist[i][j].nextvert.edno -1;
+       j1=vcs_stat.vertlist[i][j].link.edno;
        np=vcs_stat.vertlist[i][j].partcl;
-       if ( prtclbase[np-1].spin !=2 ) ind = 0; else       
+       switch(prtclbase1[np].spin)
        { 
-         lorCount++;
-         if ( ( prtclbase[np-1].cdim != 1 ) && 
-              ( (i >= vcs_stat.sizel) || (i1 < vcs_stat.sizel) ) )
-         {
-            tmp = alll; 
-            while (tmp != NULL) 
-            { 
-               if (  tmp->hlpcs[i][j]==tbosonmark) 
-               {  lorCount ++;
-                  tmp = NULL;
-               } else  tmp = tmp->next; 
-            } 
-         }
-         ind = lorCount;           
-       }      
-       vcs_stat.vertlist[i][j].lorentz=ind;
-       vcs_stat.vertlist[i1][j1].lorentz=ind;
+         case 0:;
+         case 1: ind1=0;ind2=0; break;
+         case 2:       
+              lorCount++;
+              if(PLR_PRTCL & vcs.vertlist[i][j].prop)
+              {  
+                ind1= lorCount++;
+                ind2= lorCount;
+                break;
+              }      
+              if (/* ( prtclbase1[np].cdim != 1 ) && */
+                 ( (i >= vcs_stat.sizel) || (i1 < vcs_stat.sizel) ) )
+               for(tmp = alll; tmp; tmp = tmp->next) 
+               if(tmp->hlpcs[i][j]==xbosonmark||tmp->hlpcs[i][j]==ybosonmark) 
+               { lorCount ++; break; }  
+              ind1 = lorCount; 
+              ind2 = lorCount;          
+              break;
+         case 3: ind1= ++lorCount;
+                 ind2= ++lorCount;
+                 break;
+         case 4: 
+              lorCount+=2;
+              ind1=lorCount;
+              lorCount+=2;
+              ind2=lorCount;       
+                 break;
+       }
+       vcs_stat.vertlist[i][j].lorentz=ind1;
+       vcs_stat.vertlist[i1][j1].lorentz=ind2;
     }    
   }     
 }
