@@ -118,7 +118,7 @@ static void * pCompile_cycle(int * input)
     for(c=strstr(osrc,".c"); c; c=strstr(c,".c")) c[1]='o';
      
     sprintf(command," cSrc=\"%s\"\n oSrc=\"%s\"\n"
-                    " $CC -c -I$CALCHEP/include $cSrc \n rm $cSrc\n ar r proclib_%d.a  $oSrc\n rm $oSrc\n $RANLIB proclib_%d.a",
+                    " $CC $CFLAGS -c -I$CALCHEP/include $cSrc \n rm $cSrc\n ar r proclib_%d.a  $oSrc\n rm $oSrc\n $RANLIB proclib_%d.a",
         csrc, osrc, input[0], input[0]);
     system(command);
   } 
