@@ -27,7 +27,7 @@
 #include "procvar.h"
 #include "viewdir.h"
 #include "dynamic_cs.h"
-#include "pubvar.h"
+#include "n_proc.h"
 #define tcol Green
 #define mpos 7
 #define graphpos 8
@@ -484,7 +484,7 @@ void f5_key_prog(int x)
                   " Diagrams in C-output        OF3"
                   " Widths in t-channels        OF4"
                   " Virtual W/Z decays          OF5"
-                  " Parallelization          nCORES"
+                  " Parallelization         nPROCSS"
                   " Number of QCD colors =      Nc "
                   " Nc=inf for color chains     OF2";
 /*
@@ -508,11 +508,11 @@ void f5_key_prog(int x)
     if(tWidths) improveStr(strmen,"OF4","ON ");
         else      improveStr(strmen,"OF4","OFF"); 
         
-    if(VVdecay)  improveStr(strmen,"OF5","ON ");
+    if(VWdecay)  improveStr(strmen,"OF5","ON ");
         else     improveStr(strmen,"OF5","OFF");    
                                           
   
-    improveStr(strmen,"nCORES","%d",nParProc);
+    improveStr(strmen,"nPROCSS","%d",nPROCSS);
                 
     menu1(20,16,"Switches",strmen,"s_switch_*",&pscr,&kmenu);
     switch (kmenu)
@@ -521,11 +521,11 @@ void f5_key_prog(int x)
 //      case 1: consLow=!consLow;       break;
       case 1: noPict=!noPict;         break;
       case 2: tWidths=!tWidths;       break; 
-      case 3: VVdecay=!VVdecay;cleanDecayTable();       break; 
+      case 3: VWdecay=!VWdecay;  VZdecay=VWdecay; cleanDecayTable();       break; 
       case 4: 
       { char mess[40];    
         sprintf(mess,"There are %d processors. To use ", (int) sysconf(_SC_NPROCESSORS_ONLN));
-        correctInt(20,22,mess,&nParProc,1);
+        correctInt(20,22,mess,&nPROCSS,1);
       } break;
       case 5: NcInfLimit=!NcInfLimit; break;
       case 6: NcInfCC=!NcInfCC; break;
